==> haskell-vector-instances-3.4-333-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vector-instances
version:              3.4
visibility:           public
id:                   vector-instances-3.4-5wn1ZUKhFZl101jgUMICIn
key:                  vector-instances-3.4-5wn1ZUKhFZl101jgUMICIn
license:              BSD-3-Clause
maintainer:           ekmett@gmail.com
author:               Edward Kmett
homepage:             http://github.com/ekmett/vector-instances
synopsis:             Orphan Instances for '\''Data.Vector'\''
category:             Data, Data Structures
abi:                  f689dadabe9048300acf9c8faf8fdff1
exposed:              True
exposed-modules:      Data.Vector.Instances
import-dirs:          /usr/lib/ghc-9.0.2/site-local/vector-instances-3.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/vector-instances-3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/vector-instances-3.4
hs-libraries:         HSvector-instances-3.4-5wn1ZUKhFZl101jgUMICIn
depends:
    base-4.15.1.0 comonad-5.0.8-KLyLAxsL77RIY9sRzUIx7r
    hashable-1.3.5.0-9wAI1WS8YgI32PWp14SUvr
    keys-3.12.3-BNH7ajmmtyp6P6E9XRsH5
    pointed-5.0.3-85YM7eENGRU1O3BAEom4Px
    semigroupoids-5.3.7-8Wom6VTpQQAKPnPSaWK92W
    vector-0.12.3.1-JI8sEYS2DW2BwfKSRTijMW

haddock-interfaces:
    /usr/share/doc/haskell-vector-instances/html/vector-instances.haddock

haddock-html:         /usr/share/doc/haskell-vector-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-instances-3.4-335-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vector-instances
version:              3.4
visibility:           public
id:                   vector-instances-3.4-GkS2biSlRQRGCTKHezM2o6
key:                  vector-instances-3.4-GkS2biSlRQRGCTKHezM2o6
license:              BSD-3-Clause
maintainer:           ekmett@gmail.com
author:               Edward Kmett
homepage:             http://github.com/ekmett/vector-instances
synopsis:             Orphan Instances for '\''Data.Vector'\''
category:             Data, Data Structures
abi:                  5a7af6e8d2eca0e422bc1c1ccb533626
exposed:              True
exposed-modules:      Data.Vector.Instances
import-dirs:          /usr/lib/ghc-9.0.2/site-local/vector-instances-3.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/vector-instances-3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/vector-instances-3.4
hs-libraries:         HSvector-instances-3.4-GkS2biSlRQRGCTKHezM2o6
depends:
    base-4.15.1.0 comonad-5.0.8-DJWcQCa1evuEDQJiKIMCEw
    hashable-1.3.5.0-9wAI1WS8YgI32PWp14SUvr
    keys-3.12.3-Fle4pfOvqK16jFY0ziV2g8
    pointed-5.0.3-GpKTJtYqcKT3zZqlnRAubP
    semigroupoids-5.3.7-9u0SjKd3fvKrUPeAW79t
    vector-0.12.3.1-KtKcoCRq29nJlZWgb7i8Fm

haddock-interfaces:
    /usr/share/doc/haskell-vector-instances/html/vector-instances.haddock

haddock-html:         /usr/share/doc/haskell-vector-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
